ToRelative

Trait ToRelative 

pub trait ToRelative {
    type Output: Display;

    // Required method
    fn to_relative(self) -> Self::Output;
}
Convert a path to a path relative to the current directory which implements Display.

Required Associated Types

type Output: Display

The type of the converted path that implements Display.

Required Methods

fn to_relative(self) -> Self::Output

Convert the path to a path relative to the current directory which implements Display.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a> ToRelative for &'a Utf8Path

Source

impl<'a> ToRelative for &'a Utf8PathBuf

Implementors